==> deepin-repair-tools_1.0.9.orig.tar.xz: deepin-repair-tools-1.0.9/translations/deepin-repair-tools_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.1">
<context>
    <name>DPKGRepair</name>
    <message>
        <location filename="../plugins/dpkg_repair/dpkg_repair_plugin.h" line="21"/>
        <source>DPKG Repair</source>
        <translation>DPKG修复</translation>
    </message>
</context>
<context>
    <name>DPKGRepairWidget</name>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="33"/>
        <source>Show details</source>
        <translation>显示详细过程</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="34"/>
        <source>Hide details</source>
        <translation>收起详细过程</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="39"/>
        <source>Repair</source>
        <translation>修复</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="40"/>
        <source>Done</source>
        <translation>完成</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="83"/>
        <source>Cannot install or upgrade application</source>
        <translation>软件无法正常安装或更新</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="104"/>
        <source>Repairing, please wait...</source>
        <translation>正在修复，请稍候…</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="131"/>
        <source>Repair failed</source>
        <translation>修复失败</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="134"/>
        <source>Repair succeeded</source>
        <translation>修复成功</translation>
    </message>
</context>
<context>
    <name>DiskClean</name>
    <message>
        <location filename="../plugins/disk_clean/disk_clean_plugin.h" line="22"/>
        <source>Disk Clean</source>
        <translation>磁盘空间清理</translation>
    </message>
</context>
<context>
    <name>DiskCleanWidget</name>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="62"/>
        <source>System partition</source>
        <translation>deepin系统分区</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="64"/>
        <source>Clean</source>
        <translation>清理</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="65"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="67"/>
        <source>Done</source>
        <translation>完成</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="152"/>
        <source>%1 (on %2)</source>
        <translation>%1 (on %2)</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="191"/>
        <source>Cleaning %1</source>
        <translation>正在清理%1</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="237"/>
        <source>%1 has been cleaned up</source>
        <translation>已经成功清理%1</translation>
    </message>
</context>
<context>
    <name>GrubRepair</name>
    <message>
        <location filename="../plugins/grub_repair/grub_repair_plugin.h" line="21"/>
        <source>Boot Repair</source>
        <translation>引导修复</translation>
    </message>
</context>
<context>
    <name>GrubRepairWidget</name>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="31"/>
        <source>Show details</source>
        <translation>显示详细过程</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="32"/>
        <source>Hide details</source>
        <translation>收起详细过程</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="36"/>
        <source>Repair</source>
        <translation>修复</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="37"/>
        <source>Cannot find boot menu to enter system</source>
        <translation>开机找不到启动菜单导致无法进入系统</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="41"/>
        <source>Done</source>
        <translation>完成</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="93"/>
        <source>Repairing, please wait...</source>
        <translation>正在修复，请稍候…</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="147"/>
        <source>Repair succeeded</source>
        <translation>修复成功</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="150"/>
        <source>Repair failed</source>
        <translation>修复失败</translation>
    </message>
</context>
<context>
    <name>PasswordReset</name>
    <message>
        <location filename="../plugins/password_reset/password_reset_plugin.h" line="21"/>
        <source>Password Reset</source>
        <translation>登录密码重设</translation>
    </message>
</context>
<context>
    <name>PasswordResetWidget</name>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="29"/>
        <source>Confirm</source>
        <translation>确定</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="28"/>
        <source>Reset password</source>
        <translation>重设密码</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="30"/>
        <source>Done</source>
        <translation>完成</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="31"/>
        <source>Password</source>
        <translation>密码</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="32"/>
        <source>Confirm password</source>
        <translation>重复密码</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="81"/>
        <source>Please enter a new password</source>
        <translation>请输入新密码</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="97"/>
        <source>The two passwords don&apos;t match</source>
        <translation>两次输入密码不一致</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="128"/>
        <source>Reset password successfully</source>
        <translation>重设密码成功</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="154"/>
        <source>Forgot login password</source>
        <translation>忘记登录密码</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="142"/>
        <source>%1 (on %2)</source>
        <translation>%1 (on %2)</translation>
    </message>
</context>
<context>
    <name>PermissionsRepair</name>
    <message>
        <location filename="../plugins/permissions_repair/permissions_repair_plugin.h" line="21"/>
        <source>Privilege Repair</source>
        <translation>权限修复</translation>
    </message>
</context>
<context>
    <name>PermissionsRepairWidget</name>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="23"/>
        <source>Cannot enter desktop due to privilege error</source>
        <translation>由于文件权限不正确导致无法登录桌面</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="26"/>
        <source>Repair</source>
        <translation>修复</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="27"/>
        <source>Done</source>
        <translation>完成</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="72"/>
        <source>Repairing, please wait...</source>
        <translation>正在修复，请稍候…</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="91"/>
        <source>Reset privilege successfully</source>
        <translation>系统权限已经重置成功</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="94"/>
        <source>Reset privilege failed</source>
        <translation>修复失败</translation>
    </message>
</context>
<context>
    <name>ScanningPage</name>
    <message>
        <location filename="../src/scanningpage.cpp" line="27"/>
        <source>Checking hard disk status, please wait...</source>
        <translation>正在检查硬盘状态，请稍候...</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="34"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="36"/>
        <source>Repair</source>
        <translation>修复</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="40"/>
        <source>Restart Now</source>
        <translation>重新启动</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="139"/>
        <source>Hard disk partition %1 error, please repair</source>
        <translation>检测到硬盘分区%1需要修复</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="151"/>
        <source>Please restart your computer to finish repairing</source>
        <translation>为确保硬盘修复生效，请重新启动</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="177"/>
        <source>Repairing hard disk, please wait...</source>
        <translation>正在修复硬盘，请稍候…</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="140"/>
        <source>The repair may cause data loss, please confirm and continue</source>
        <translation>修复可能会造成部分数据丢失，请确认后再继续</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="38"/>
        <source>Done</source>
        <translation>完成</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="150"/>
        <source>Repair succeeded</source>
        <translation>硬盘修复成功</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="156"/>
        <source>Repair failed</source>
        <translation>硬盘修复失败</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../src/main.cpp" line="45"/>
        <source>Deepin Repair</source>
        <translation>深度系统修复工具</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="46"/>
        <source>Deepin Repair is a tool to help users quickly fix some issues in deepin, including hard disk detecting, disk cleaning, DPKG repairing, boot repairing, privilege repairing, password reset, etc.</source>
        <translation>深度系统修复工具是一款帮助用户快速修复深度操作系统中某些问题的工具，其中包含硬盘检测、磁盘空间清理、DPKG修复、引导修复、权限修复、登录密码重设等。</translation>
    </message>
</context>
</TS>

==> deepin-repair-tools_1.0.14.orig.tar.xz: deepin-repair-tools-1.0.14/translations/deepin-repair-tools_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.1">
<context>
    <name>DPKGRepair</name>
    <message>
        <location filename="../plugins/dpkg_repair/dpkg_repair_plugin.h" line="21"/>
        <source>DPKG Repair</source>
        <translation>DPKG修复</translation>
    </message>
</context>
<context>
    <name>DPKGRepairWidget</name>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="33"/>
        <source>Show details</source>
        <translation>显示详细过程</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="34"/>
        <source>Hide details</source>
        <translation>收起详细过程</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="39"/>
        <source>Repair</source>
        <translation>修复</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="40"/>
        <source>Done</source>
        <translation>完成</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="83"/>
        <source>Cannot install or upgrade application</source>
        <translation>软件无法正常安装或更新</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="104"/>
        <source>Repairing, please wait...</source>
        <translation>正在修复，请稍候…</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="131"/>
        <source>Repair failed</source>
        <translation>修复失败</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="134"/>
        <source>Repair successful</source>
        <translation>修复成功</translation>
    </message>
</context>
<context>
    <name>DiskClean</name>
    <message>
        <location filename="../plugins/disk_clean/disk_clean_plugin.h" line="22"/>
        <source>Disk Clean</source>
        <translation>磁盘清理</translation>
    </message>
</context>
<context>
    <name>DiskCleanWidget</name>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="62"/>
        <source>System partition</source>
        <translation>deepin系统分区</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="64"/>
        <source>Clean</source>
        <translation>清理</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="65"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="67"/>
        <source>Done</source>
        <translation>完成</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="153"/>
        <source>%1 (on %2)</source>
        <translation>%1 (on %2)</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="192"/>
        <source>Cleaning %1</source>
        <translation>正在清理%1</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="238"/>
        <source>%1 has been cleaned up</source>
        <translation>已经成功清理%1</translation>
    </message>
</context>
<context>
    <name>GrubRepair</name>
    <message>
        <location filename="../plugins/grub_repair/grub_repair_plugin.h" line="21"/>
        <source>Boot Repair</source>
        <translation>引导修复</translation>
    </message>
</context>
<context>
    <name>GrubRepairWidget</name>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="31"/>
        <source>Show details</source>
        <translation>显示详细过程</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="32"/>
        <source>Hide details</source>
        <translation>收起详细过程</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="36"/>
        <source>Repair</source>
        <translation>修复</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="37"/>
        <source>Cannot find boot menu to enter system</source>
        <translation>开机找不到启动菜单导致无法进入系统</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="41"/>
        <source>Done</source>
        <translation>完成</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="93"/>
        <source>Repairing, please wait...</source>
        <translation>正在修复，请稍候…</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="147"/>
        <source>Repair successful</source>
        <translation>修复成功</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="150"/>
        <source>Repair failed</source>
        <translation>修复失败</translation>
    </message>
</context>
<context>
    <name>PasswordReset</name>
    <message>
        <location filename="../plugins/password_reset/password_reset_plugin.h" line="21"/>
        <source>Password Reset</source>
        <translation>密码重置</translation>
    </message>
</context>
<context>
    <name>PasswordResetWidget</name>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="29"/>
        <source>Confirm</source>
        <translation>确定</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="28"/>
        <source>Reset password</source>
        <translation>重设密码</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="30"/>
        <source>Done</source>
        <translation>完成</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="31"/>
        <source>Password</source>
        <translation>密码</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="32"/>
        <source>Confirm password</source>
        <translation>重复密码</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="81"/>
        <source>Please enter a new password</source>
        <translation>请输入新密码</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="97"/>
        <source>Passwords do not match</source>
        <translation>两次输入密码不一致</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="130"/>
        <source>Reset password successfully</source>
        <translation>重设密码成功</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="156"/>
        <source>Forgot login password</source>
        <translation>忘记登录密码</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="144"/>
        <source>%1 (on %2)</source>
        <translation>%1 (on %2)</translation>
    </message>
</context>
<context>
    <name>PermissionsRepair</name>
    <message>
        <location filename="../plugins/permissions_repair/permissions_repair_plugin.h" line="21"/>
        <source>Privilege Repair</source>
        <translation>权限修复</translation>
    </message>
</context>
<context>
    <name>PermissionsRepairWidget</name>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="23"/>
        <source>Cannot enter desktop due to privilege error</source>
        <translation>由于文件权限不正确导致无法登录桌面</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="26"/>
        <source>Repair</source>
        <translation>修复</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="27"/>
        <source>Done</source>
        <translation>完成</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="71"/>
        <source>Repairing, please wait...</source>
        <translation>正在修复，请稍候…</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="90"/>
        <source>Reset privilege successfully</source>
        <translation>系统权限已经重置成功</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="93"/>
        <source>Reset failed</source>
        <translation>修复失败</translation>
    </message>
</context>
<context>
    <name>ScanningPage</name>
    <message>
        <location filename="../src/scanningpage.cpp" line="27"/>
        <source>Checking hard disk status, please wait...</source>
        <translation>正在检查硬盘状态，请稍候...</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="34"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="37"/>
        <source>Repair</source>
        <translation>修复</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="41"/>
        <source>Restart Now</source>
        <translation>重新启动</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="149"/>
        <source>Hard disk partition %1 error, please repair</source>
        <translation>检测到硬盘分区%1需要修复</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="160"/>
        <source>Repair successful</source>
        <translation>硬盘修复成功</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="161"/>
        <source>Please restart your computer to finish repairing</source>
        <translation>为确保硬盘修复生效，请重新启动</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="187"/>
        <source>Repairing hard disk, please wait...</source>
        <translation>正在修复硬盘，请稍候…</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="150"/>
        <source>The repair may cause data loss, please confirm and continue</source>
        <translation>修复可能会造成部分数据丢失，请确认后再继续</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="39"/>
        <source>Done</source>
        <translation>完成</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="166"/>
        <source>Repair failed</source>
        <translation>硬盘修复失败</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../src/main.cpp" line="47"/>
        <source>Deepin Repair</source>
        <translation>深度系统修复工具</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="48"/>
        <source>Deepin Repair is a tool to help users quickly fix some issues in deepin, including hard disk detecting, disk cleaning, DPKG repairing, boot repairing, privilege repairing, password reset, etc.</source>
        <translation>深度系统修复工具是一款帮助用户快速修复深度操作系统中某些问题的工具，其中包含硬盘检测、磁盘空间清理、DPKG修复、引导修复、权限修复、登录密码重设等。</translation>
    </message>
</context>
</TS>
